## Install the package
```
pip install mlsgraphcreator
```
Make sure that your file is in CSV format.

## Usage
``` python
from mlsgraphcreator import graphcreator
graphcreator.createGraph('path/to/csv/file')
```
